/*	Copyright (C) 2003-2010 Free Electron Organization
	Any use of this software requires a license.  If a valid license
	was not distributed with this file, visit freeelectron.org. */

#include "maya/maya.pmh"

namespace fe
{

I32 SurfaceAccessorMaya::createBlindDataID(String a_attrName,String a_attrType)
{
	const String attrKey=a_attrName+":"+a_attrType;
	I32& rBlindDataID=m_spMaster->catalog()->catalog<I32>(
			"MayaBlindID",attrKey,-1);

	if(rBlindDataID>=0)
	{
		//* created already
		return rBlindDataID;
	}

#if FE_SAM_BLIND_DEBUG
	feLog("SurfaceAccessorMaya::createBlindDataID"
			" creating blind data for \"%s\"\n",attrKey.c_str());
#endif

	rBlindDataID=0x0;
	while(m_pFnMesh->isBlindDataTypeUsed(rBlindDataID))
	{
		rBlindDataID++;
	}

#if FE_SAM_BLIND_DEBUG
	feLog("SurfaceAccessorMaya::createBlindDataID"
			" blindDataID %d\n",rBlindDataID);
#endif

	MStringArray longNames;
	MStringArray shortNames;
	MStringArray formatNames;

	// format names: int float double boolean string binary

	longNames.append(a_attrName.c_str());
	shortNames.append(a_attrName.c_str());

	if(a_attrType=="Real" || a_attrType=="SpatialVector")
	{
		formatNames.append("double");
	}
	else if(a_attrType=="I32")
	{
		formatNames.append("int");
	}

	MStatus status=m_pFnMesh->createBlindDataType(
			rBlindDataID,longNames,shortNames,formatNames);
	if(!status)
	{
		feLog("SurfaceAccessorMaya::createBlindDataID"
				" createBlindDataType %p failed\n",rBlindDataID);
	}

	return rBlindDataID;
}

void SurfaceAccessorMaya::updateGroupList(void)
{
	m_groupList.clear();
	if(m_attrName.empty())
	{
		return;
	}
	if(m_element!=SurfaceAccessibleI::e_pointGroup &&
			m_element!=SurfaceAccessibleI::e_primitiveGroup)
	{
		return;
	}

	SurfaceAccessibleI::Element storeElement=m_element;

	//* temporary switch to use common methods
	if(m_element==SurfaceAccessibleI::e_pointGroup)
	{
		m_element=SurfaceAccessibleI::e_point;
	}
	else
	{
		m_element=SurfaceAccessibleI::e_primitive;
	}

	//* TODO scan all points/primitives
	//* if group attribute non-zero, add to group list

	const U32 elements=count();
	for(U32 index=0;index<elements;index++)
	{
		if(integer(index)>0)
		{
			m_groupList.push_back(index);
		}
	}

	//* restore original
	m_element=storeElement;
}

} // namespace
